# IPM Decisions models in VIPS
The [Horizon 2020](https://research-and-innovation.ec.europa.eu/funding/funding-opportunities/funding-programmes-and-open-calls/horizon-2020_en) project [IPM Decisions](https://ipmdecisions.net/) has produced a 

__*[..]“one stop shop” for decisions support in integrated pest management. It is a web-based framework providing farmers, advisors and researchers access to a wide range of Decision Support Systems and weather data from across Europe through a set of four dashboards[...]*__

A curated set of European DSSs and weather data sources have been made available in the platform through APIs developed by [NIBIO](https://nibio.no/en), [Met Norway](https://www.met.no/en) and [LUKE](https://www.luke.fi/en).

* [IPM Decisions DSS API](https://github.com/H2020-IPM-Decisions/DSSService)
* [IPM Decisions Weather API](https://github.com/H2020-IPM-Decisions/WeatherService)

The DSSs have been made available through the [IPM Decisions platform](https://platform.ipmdecisions.net/) (see screenshot below) where farmers, advisors and researchers can log in and configure their farm and fields and choose between the available DSSs. Weather data can either be provided by the user's private weather station or by the open weather data sources available in the platform.

<img src="README_img_01.png" alt="Screenshot of the IPM Decisions platform"/>

_Screenshot of the IPM Decisions platform_

The APIs are designed as web services that are open for use by other clients than the IPM Decisions platform. This means that a DSS provider can use the APIs to discover and make other DSSs available directly from their DSS platform/web page, without having to implement the algorithms for that DSS. In the platform, meta data are available for all DSSs and weather data sources. These meta data are structured in a way that as soon as  client code has been implemented for one DSS (from IPM Decisions), only minimal adaptations are needed to add new DSSs (from IPM Decisions).

## Saddle gall midge model from ADAS made available in VIPS

In VIPS, we have created a web page to test/run the Saddle Gall Midge model developed and hosted by the UK advisory organization [ADAS](https://adas.co.uk/). The code for this is found in these files:

### `static/ipmdlib.js`
This file contains JavaScript functions for retrieving metadata, showing data in maps and displaying results. They are intended to be usable for all potential uses of the IPM Decisions API.

### `templates/ipmd/saddlegallmidgeform.html`
This file is specific for the Saddle Gall Midge model, but contains a lot of JavaScript code, some of which probably could be refactored and moved into `ipmdlib.js`

### Workflow/data flow of the application
After the browser has rendered the page and the document is ready, this is what happens

#### 1. Retrieve and display metadata for the Saddle Gall Midge model
The application sends a request to the IPM Decisions platform for metadata about the model. It pulls the `description` out of the returned data and displays it in a box on the page (see screenshots)

**TODO: Add client-server-diagram**

<img src="README_img_02.png" alt="Screenshot of the upper part of the model web page"/>

_Screenshot of the upper part of the model web page_

The metadata also accurately and machine readably describes the input data that it needs, using Json schema. Here's the input data definition for the Saddle Gall Midge model:

```json
{
    "type":"object",
    "properties": {  
        "modelId": {"type": "string", "pattern":"^HAPDMA$", "title": "Model Id", "default":"HAPDMA", "description":"Must be HAPDMA"},
        "weatherData": {
        "$ref": "https://platform.ipmdecisions.net/api/wx/rest/schema/weatherdata"
        },
        "optionalData" :{
        "title":"Optional parameters for the DSS",
        "type": "object",
        "properties": {
            "rain_threshold": {"type": "number", "default":"1","title": "Rainfall Threshold" },
            "dry_day": {"type": "number", "default":"3", "title": "Dry Day Threshold"},
            "temp_threshold": {"type": "number", "default":"0", "title": "Temperature Threshold"},
            "degree_day": {"type": "number", "default":"512", "title": "Degree Days"},
            "startDate": {"type":"string","format": "date", "title": "Model Start Date/Biofix (YYYY-MM-DD)", "default": "{CURRENT_YEAR}-03-01"},
            "endDate": {"type":"string","format": "date", "title": "Model End Date (YYYY-MM-DD)", "default": "{CURRENT_YEAR}-07-31"}
        }
        }
    },
    "required": ["modelId"]
}
```

We are using the [JSON Editor JavaScript library](https://github.com/json-editor/json-editor) to automatically render this schema into an HTML Form (see the screenshot above). The JSON Editor also validates the input data and upon submission formats the entered data into Json.

#### 2. Retrieve and display metadata for all available weather data sources
The application

**TODO: Add client-server-diagram**